@@ -46,11 +46,13 @@ function(var,path,pattern,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
 
   file=filelist[1]
   file <- paste(path,"/",file,sep="")
+  
   id <- nc_open(file)
 
-  # get information about dimensions
+  # get information about dimensions and attributes
   
-  dimnames <- names(id$dim)
+  dimnames   <- names(id$dim)
+  global_att <- ncatt_get(id,0)
 
  # check standard_names of dimensions
     for (i in 1:length(dimnames)){
@@ -113,23 +115,23 @@ function(var,path,pattern,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
 	      assign(v_att_list[i],att_dum$value)}
     }
 
-      # get data of first file and cut desired region
+    # get data of first file and cut desired region
 
-	lon <- ncvar_get(id,lon_name)
-	lat <- ncvar_get(id,lat_name)
-	time1 <- ncvar_get(id,t_name)
-	time_len <- length(time1)
-	if ("time_bnds" %in% varnames){
-	  tbnds1 <- ncvar_get(id,"time_bnds")
-	}
+	  lon <- ncvar_get(id,lon_name)
+	  lat <- ncvar_get(id,lat_name)
+	  time1 <- ncvar_get(id,t_name)
+	  time_len <- length(time1)
+	  if ("time_bnds" %in% varnames){
+	    tbnds1 <- ncvar_get(id,"time_bnds")
+	  }
 	
-	lon_limit <- which(lon>=lon1&lon<=lon2)  
-	lat_limit <- which(lat>=lat1&lat<=lat2) 
+	  lon_limit <- which(lon>=lon1&lon<=lon2)  
+	  lat_limit <- which(lat>=lat1&lat<=lat2) 
 
-	lon <- lon[lon_limit]
-	lat <- lat[lat_limit]
+	  lon <- lon[lon_limit]
+	  lat <- lat[lat_limit]
   
-  # check for empty lon_limit or lat_limit
+    # check for empty lon_limit or lat_limit
   
     if (length(lon_limit)==0|length(lat_limit)==0){
       nc_close(id)
@@ -192,6 +194,22 @@ function(var,path,pattern,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
     cmsaf_info <- (paste("cmsaf::box_mergetime for variable ",var,sep=""))
     target[is.na(target)] <- v_missing_value
     nb2 <- c(0,1)
+    
+    # prepare global attributes
+    global_att_default <- c("institution","title","summary","id","creator_name",
+                            "creator_email","creator_url","creator_type","publisher_name",
+                            "publisher_email","publisher_url","publisher_type",
+                            "references","keywords_vocabulary","keywords","project",
+                            "standard_name_vocabulary","geospatial_lat_units",
+                            "geospatial_lon_units","geospatial_lat_resolution",
+                            "geospatial_lon_resolution","platform_vocabulary","platform",
+                            "instrument_vocabulary","instrument","date_created","product_version",
+                            "producer","version","dataset_version","source")
+    
+    global_att_list <- names(global_att)
+    
+    global_att_list <- global_att_list[toupper(global_att_list) %in% toupper(global_att_default)]
+    global_att <- global_att[global_att_list]
 
     x <- ncdim_def(name="lon",units=lon_units,vals=lon)
     y <- ncdim_def(name="lat",units=lat_units,vals=lat)
@@ -228,7 +246,13 @@ function(var,path,pattern,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
       ncatt_put(ncnew,"lat","axis",lat_axis,prec="text")
 
       ncatt_put(ncnew,0,"Info",info,prec="text")
-
+      
+      if (length(global_att_list)>0){
+        for (iglob in 1:length(global_att_list)){
+          ncatt_put(ncnew,0,global_att_list[iglob],global_att[iglob][[1]],prec="text")
+        }
+      }
+      
     } else {
       vars <- list(var1)
       ncnew <- nc_create(outfile,vars,force_v4=nc_format)
@@ -251,6 +275,12 @@ function(var,path,pattern,outfile,lon1=-180,lon2=180,lat1=-90,lat2=90,nc34=3){
       ncatt_put(ncnew,"lat","axis",lat_axis,prec="text")
 
       ncatt_put(ncnew,0,"Info",info,prec="text")
+      
+      if (length(global_att_list)>0){
+        for (iglob in 1:length(global_att_list)){
+          ncatt_put(ncnew,0,global_att_list[iglob],global_att[iglob][[1]],prec="text")
+        }
+      }
     }
     
   # check timestep sorting
